==> haskell-vault-0.3.1.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vault
version: 0.3.1.0
id: vault-0.3.1.0-ESmbOwQWFka2w0IX2fxk6I
key: vault-0.3.1.0-ESmbOwQWFka2w0IX2fxk6I
license: BSD-3-Clause
copyright: (c) Heinrich Apfelmus 2011-2013
maintainer: Heinrich Apfelmus <apfelmus at quantentunnel de>
author: Heinrich Apfelmus, Elliott Hird
homepage: https://github.com/HeinrichApfelmus/vault
synopsis: a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.
    .
    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.
    .
    Also provided is a /locker/ type, representing a store for a single element.
category: Data
abi: 9f0b33ac48fb4bea8f68a8085641a3ec
exposed: True
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict
import-dirs: /usr/lib/ghc-8.4.2/site-local/vault-0.3.1.0
library-dirs: /usr/lib/ghc-8.4.2/site-local/vault-0.3.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/vault-0.3.1.0
hs-libraries: HSvault-0.3.1.0-ESmbOwQWFka2w0IX2fxk6I
depends:
    base-4.11.1.0 containers-0.5.11.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    unordered-containers-0.2.9.0-A3KBTFupd4vFLOQxsI6884
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0e3ad496fde59157bcd6a630b4b29548
             unordered-containers-0.2.9.0-A3KBTFupd4vFLOQxsI6884=c76b79dc8a56ff4425c082d0052b04f4
haddock-interfaces: /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html: /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vault-0.3.1.1-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: vault
version: 0.3.1.1
id: vault-0.3.1.1-1I3U5gnLacC7WC9szfmOnv
key: vault-0.3.1.1-1I3U5gnLacC7WC9szfmOnv
license: BSD-3-Clause
copyright: (c) Heinrich Apfelmus 2011-2013
maintainer: Heinrich Apfelmus <apfelmus at quantentunnel de>
author: Heinrich Apfelmus, Elliott Hird
homepage: https://github.com/HeinrichApfelmus/vault
synopsis: a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.
    .
    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.
    .
    Also provided is a /locker/ type, representing a store for a single element.
category: Data
abi: 88d86e730c3d0fe0dcb4b43589245de1
exposed: True
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict
import-dirs: /usr/lib/ghc-8.4.2/site-local/vault-0.3.1.1
library-dirs: /usr/lib/ghc-8.4.2/site-local/vault-0.3.1.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/vault-0.3.1.1
hs-libraries: HSvault-0.3.1.1-1I3U5gnLacC7WC9szfmOnv
depends:
    base-4.11.1.0 containers-0.5.11.0
    hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg
    unordered-containers-0.2.9.0-A3KBTFupd4vFLOQxsI6884
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             containers-0.5.11.0=f8334bacfaf0e925ca7b24fb26fb2e66
             hashable-1.2.7.0-KBRKfoLB8Vi3u8lTX7XQlg=0e3ad496fde59157bcd6a630b4b29548
             unordered-containers-0.2.9.0-A3KBTFupd4vFLOQxsI6884=c76b79dc8a56ff4425c082d0052b04f4
haddock-interfaces: /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html: /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
